#!/bin/bash
# Copyright(c) 2022 Gene N. All rights reserved.
# License: MIT https://opensource.org/licenses/MIT

# This program relies on the LST calculator, a 'c' program
# FIrst copy both this script and the lst.c to some directory
# Compile the lst.c
#   gcc -o lst lst.c
#
# Execute this script
# ./move_ncp.sh YOUR_LONGITUDE_IN_DECIMAL_DEGREES


# Change to your INDI device identifier
DRIVER="Telescope Simulator"

#change to the Dec you want to move to
DECLINATION=90.0

# Logitude comes from the command line
LONGITUDE=$1

if [ $# -eq 0 ]
 then
    echo "Need Longitude"
    echo "Usage: $0 Longitude"
    echo "Where Longitude is in decimal degrees"
    exit
fi
indi_setprop "$DRIVER.CONNECTION.CONNECT=On"

IJ=`indi_getprop -1 "$DRIVER.CONNECTION.CONNECT"`
while [ "$IJ" != "On" ]
 do
    sleep 1
    echo Waiting to connect to  = $IJ
    IJ=`indi_getprop -1 "$DRIVER.CONNECTION.CONNECT"`
done
echo Result Connect to $DRIVER = `indi_getprop -1 "$DRIVER.CONNECTION.CONNECT"`
PARKSTATE=`indi_getprop -1 "$DRIVER.TELESCOPE_PARK.PARK"`
echo "ParkState =" +$PARKSTATE
if [ "$PARKSTATE" = "On" ]
  then
    echo "Unpark the telescope (Y/y) ?"
    read YESNO
    if [ "$YESNO" = "Y" ] || [ "$YESNO" = "y" ]
      then
        echo "GOT YES"
        indi_setprop "$DRIVER.TELESCOPE_PARK.UNPARK=On"
      else
        echo "Did not get YES, telescope park state unchanged"
        echo "Since is parked, nothing to do, exiting"
        exit
    fi
  else
    echo "Telescope reported unparked, continuing"
fi
TRACKSTATE=`indi_getprop -1 "$DRIVER.TELESCOPE_TRACK_STATE.TRACK_ON"`
echo "Tracking State =" +$TRACKSTATE
if [ "$TRACKSTATE" != "On" ]
  then
    echo "Turn tracking on (Y/y) ?"
    read YESNO
    if [ "$YESNO" = "Y" ] || [ "$YESNO" = "y" ]
      then
        echo "GOT YES"
        indi_setprop "$DRIVER.TELESCOPE_TRACK_STATE.TRACK_ON=On"
      else
        echo "Did not get YES, telescope tracking state unchanged"
        exit
    fi
  else
    echo "Telescope reported tracking on, continuing"
fi
IRA=`./lst $LONGITUDE`
IRA1=(${IRA//;/ })
RA=${IRA1[0]}
RAHMS=${IRA1[1]}
echo "Perform slew to $RAHMS (Y/y) ?"

read YESNO
if [ "$YESNO" = "Y" ] || [ "$YESNO" = "y" ]
  then
    echo "GOT YES"
    indi_setprop "Telescope Simulator.ON_COORD_SET.SLEW=On"
    echo "Setting to RA = $RA"
    indi_setprop "$DRIVER.EQUATORIAL_EOD_COORD.RA;DEC=$RA;$DECLINATION"
    indi_setprop "Telescope Simulator.ON_COORD_SET.TRACK=On"
  else
    echo "Did not get YES, telescope location unchanged"
    exit
fi
exit
